@@ -13,6 +13,7 @@ import requests
 from pathlib import Path
 from typing import Dict, Any, Optional, Tuple
 from getpass import getpass
+import importlib.resources
 
 from .exceptions import (
     PluginSDKError,
@@ -75,8 +76,14 @@ class PluginClient:
         """
         try:
             # 获取示例插件目录的路径
-            current_dir = Path(__file__).parent.parent
-            example_plugin_dir = current_dir / "example-python-plugin"
+            # 使用importlib.resources访问包内的资源
+            try:
+                example_plugin_ref = importlib.resources.files("xcoding_plugin") / ".." / "example-python-plugin"
+                example_plugin_dir = Path(str(example_plugin_ref))
+            except (AttributeError, ImportError):
+                # 如果importlib.resources不可用，回退到旧方法
+                current_dir = Path(__file__).parent.parent
+                example_plugin_dir = current_dir / "example-python-plugin"
             
             if not example_plugin_dir.exists():
                 raise PluginInitializationError(f"示例插件目录不存在: {example_plugin_dir}")
